@@ -16,18 +16,18 @@
 [08:22] <siTol> Ravi: z kad tego braina sciagac
 %
 13:44:34 < user[13]> b|b: uzyj ipv6calc
-13:44:35 <@Westbam> 9.3.3.0.2.0.0.0.e.a.0.0.0.1.0.8.e.f.f.3.ip6.int  kole.
+13:44:35 <@Westbam> 9.3.3.0.2.0.0.0.e.a.0.0.0.1.0.8.e.f.f.3.ip6.int  koleś.
 13:45:05 < user[13]> ipv6calc -r 3ffe:8010:ae:2:339::/80
 13:45:14 < user[13]> dostaniesz to co napisal Westbam :)
-13:45:37 <@Westbam> trzeba mie te troch w gowie a nie w /usr/bin/ ;p
+13:45:37 <@Westbam> trzeba mieć też trochę w głowie a nie w /usr/bin/ ;p
 13:45:46 < user[13]> ;)
 13:46:26 < user[13]> czy jak masz pilota to zeby przelaczyc program
                      podchodzisz do telewizora ? :)
-13:46:44 <@Westbam> nie ale jak ci schowam 'start' w windowsie to si
+13:46:44 <@Westbam> nie ale jak ci schowam 'start' w windowsie to się
                     pogubisz.
 13:46:54 < user[13]> hehe
 13:48:13 < user[13]> zalezy jak schowasz :]
-13:48:24 <@Westbam> albo wyjm ci baterie z pilota.
+13:48:24 <@Westbam> albo wyjmę ci baterie z pilota.
 13:48:35 < user[13]> :>
 %
 18:25:07 >> #ipv6.pl JOIN Valdi_ (admin@pa145.mysliborz.sdi.tpnet.pl)
@@ -47,18 +47,18 @@
 22:18:06 < user[13]> i oglada z zaciekawieniem :>
 %
 22:22:59 < user[13]> co sie stalo z ipv6.pl ?
-22:23:21 <@Ravi> myszy zjady
+22:23:21 <@Ravi> myszy zjadły
 22:24:26 < user[13]> e
 22:25:30 < user[13]> az takie glodne byly ?
 22:25:34 <@Ravi> widocznie.
 22:25:36 < user[13]> to bede pilnowal zeby mi domu nie zjadly ;>
 %
 15:36:33 <@chatul> kto mnie szukal i dlaczego ?
-15:37:07 <@Ravi> ja, bo chciaem Ci da buziaka :*
+15:37:07 <@Ravi> ja, bo chciałem Ci dać buziaka :*
 15:37:41 <@Westbam> mhyhyhy
 15:38:46 < djrzulf> ostro
 15:38:46 < djrzulf> ;]
-15:39:00 <@Ravi> Jestem kochankiem werterowskim i przeywam niespenion
-                 mio do Ciebie i djrzulfa.
+15:39:00 <@Ravi> Jestem kochankiem werterowskim i przeżywam niespełnioną
+                 miłość do Ciebie i djrzulfa.
 %
 
